From: Stephen Touset Date: 2010-06-25T05:33:51+09:00 Subject: [ruby-core:30885] [Bug #3478] Excruciatingly slow pathname implementation Bug #3478: Excruciatingly slow pathname implementation http://redmine.ruby-lang.org/issues/show/3478 Author: Stephen Touset Status: Open, Priority: Normal Category: lib ruby -v: ruby 1.9.1p378 (2010-01-10 revision 26273) [i386-darwin10.3.1] In writing a pure-Ruby git implementation, I discovered with rprof that using Pathname was the source of a huge proportion of my library's running time. Recently, Rails contributor Jos�� Valim discovered a similar situation in Rails. Anecdotally, removing Pathname resulted in a speedup from 6s to 3s on a single request. Here's his commit removing some Pathname usage from Rails: http://github.com/rails/rails/commit/69abbe893413c99808c8cebd2f1d468c7921c573 I have rewritten Pathname, and the project is on GitHub. http://github.com/stouset/pathname3/ I've included the rewrite as a patch. It's backwards-compatible with the existing Pathname class, and passes RubySpec and MRI tests. ---------------------------------------- http://redmine.ruby-lang.org